pub fn extract_witness(
pre_sig: &AdaptorPreSig,
full_sig: &Signature,
) -> Option<Scalar>Expand description
Extract the witness y from a completed signature and pre-signature. Anyone who sees both can recover y.
pub fn extract_witness(
pre_sig: &AdaptorPreSig,
full_sig: &Signature,
) -> Option<Scalar>Extract the witness y from a completed signature and pre-signature. Anyone who sees both can recover y.